pub struct LoRaInterface<'a, SPI, BUSY, DIO1, RST, DLY> { /* private fields */ }Implementations
Sourceimpl<'a, SPI, BUSY, DIO1, RST, DLY> LoRaInterface<'a, SPI, BUSY, DIO1, RST, DLY>
impl<'a, SPI, BUSY, DIO1, RST, DLY> LoRaInterface<'a, SPI, BUSY, DIO1, RST, DLY>
Sourcepub fn interface_id(profile: &RadioProfile) -> InterfaceId
pub fn interface_id(profile: &RadioProfile) -> InterfaceId
The id a radio on profile will carry — for the caller that stands its EmbassyInterfaceStatus up under the same key before building the interface.
pub fn new( input: LoRaInterfaceInput<'a, SPI, BUSY, DIO1, RST, DLY>, ) -> Result<Self, LoRaConfigError>
pub fn id(&self) -> InterfaceId